BarometerValue class

Constructors

BarometerValue(double hectpascal)
const

Properties

atm → double
no setter
hashCode → int
The hash code for this object.
no setterinherited
hectpascal → double
final
inchOfMercury → double
no setter
millimeterOfMercury → double
no setter
poundsSquareInch → double
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited